Class: Symbol
Overview
Extensions to the Symbol class.
Instance Method Summary collapse
-
#to_instance_variable_name ⇒ Object
Return a duplicate of the symbol in a format ready to dynamically generate an instance variable.
-
#to_ivar_label ⇒ Object
Convenience method for to_instance_variable_name().
Instance Method Details
#to_instance_variable_name ⇒ Object
Return a duplicate of the symbol in a format ready to dynamically generate an instance variable.
6 7 8 9 10 |
# File 'lib/aastdlib/symbol.rb', line 6 def to_instance_variable_name return self.to_s.to_instance_variable_name end |
#to_ivar_label ⇒ Object
Convenience method for to_instance_variable_name()
13 14 15 16 17 |
# File 'lib/aastdlib/symbol.rb', line 13 def to_ivar_label() return self.to_instance_variable_name() end |